**To stop an IoT Device Advisor test suite that is currently running**

The following ``stop-suite-run`` example stops a device advisor test suite that is currently running with the specified suite definition ID and suite run ID. ::

    aws iotdeviceadvisor stop-suite-run \
        --suite-definition-id qqcsmtyyjabl \
        --suite-run-id nzlfyhaa18oa

This command produces no output.

For more information, see `Stop a test suite run <https://docs.aws.amazon.com/iot/latest/developerguide/device-advisor-workflow.html#device-advisor-workflow-stop-suite-run>`__ in the *AWS IoT Core Developer Guide*.
